@@ -23,7 +23,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: page-info-dialog.c,v 1.43 2005/03/03 10:59:12 chpe Exp $
+ *  $Id: page-info-dialog.c,v 1.43.2.1 2005/03/21 20:38:42 chpe Exp $
  */
 
 #include "config.h"
@@ -2075,5 +2075,7 @@ page_info_dialog_new (EphyWindow *window,
 			     "parent-window", window,
 			     "window", window,
 			     "embed", embed,
+			     "default-width", 500,
+			     "default-height", 400,
 			     NULL);
 }
