@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: mozilla-selection.cpp,v 1.3 2004/12/08 15:33:53 chpe Exp $
+ *  $Id: mozilla-selection.cpp,v 1.3.2.1 2005/04/07 11:47:08 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -27,9 +27,9 @@
 
 #include <glib.h>
 
-#define MOZILLA_STRICT_API
+#undef MOZILLA_INTERNAL_API
 #include <nsEmbedString.h>
-#undef MOZILLA_STRICT_API
+#define MOZILLA_INTERNAL_API 1
 #include <nsCOMPtr.h>
 #include <nsISelection.h>
 #include <gtkmozembed.h>
